Modules
Structs
An implementation of
Progress which can be created easily from Option<impl Progress>.A type identifying a spot in the hierarchy of
Tree items.The value associated with a spot in the hierarchy.
Emit a message with throughput information when the instance is dropped.
Progress associated with some item in the progress tree.
Enums
Indicate whether a progress can or cannot be made.
Constants
The default Id to use if there is no need for an id.
Type Definitions
Four bytes of function-local unique and stable identifier for each item added as progress,
like b“TREE“ or b“FILE“.
The amount of steps a progress can make
As step, but shareable.