Struct prodash::progress::Value

source ·
pub struct Value {
    pub step: StepShared,
    pub done_at: Option<Step>,
    pub unit: Option<Unit>,
    pub state: State,
}
Progress associated with some item in the progress tree.

Fields

step: StepShared

The amount of progress currently made

done_at: Option<Step>

The step at which no further progress has to be made.

If unset, the progress is unbounded.

unit: Option<Unit>

The unit associated with the progress.

state: State

Whether progress can be made or not

Implementations

Returns a number between Some(0.0) and Some(1.0), or None if the progress is unbounded.

A task half done would return Some(0.5).