pub struct Human {
pub name: &'static str,
pub formatter: Formatter,
}Expand description
A helper for formatting numbers in a format easily read by humans in renderers, as in 2.54 million objects
Fields
name: &'static strThe name of the represented unit, like ‘items’ or ‘objects’.
formatter: FormatterThe formatter to format the actual numbers.
Implementations