pub struct Range {
pub name: &'static str,
}Expand description
A helper for formatting numbers representing ranges in renderers as in 2 of 5 steps.
Fields
name: &'static strThe name of the unit to be appended to the range.
Implementations