Modules
- Various utilities to display values and units.
Structs
- A marker for formatting numbers as bytes in renderers.
- A marker for formatting numbers as duration in renderers, as in
7d4h20m10s. - A helper for formatting numbers in a format easily read by humans in renderers, as in
2.54 million objects - A helper for formatting numbers representing ranges in renderers as in
2 of 5 steps. - A configurable and flexible unit for use in Progress::init().
Enums
- Either a static label or a dynamic one implementing
DisplayValue.
Traits
- A trait to encapsulate all capabilities needed to display a value with unit within a renderer.
Functions
- Returns a unit that is a dynamic
label. - Returns a unit that is a dynamic
labelalong with information on where to display a fraction and throughput. - Returns a unit that is a static
label. - Returns a unit that is a static
labelalong with information on where to display a fraction and throughput.